summaryrefslogtreecommitdiffstats
path: root/chromium/cc/mojo_embedder/async_layer_tree_frame_sink.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/cc/mojo_embedder/async_layer_tree_frame_sink.h')
-rw-r--r--chromium/cc/mojo_embedder/async_layer_tree_frame_sink.h27
1 files changed, 17 insertions, 10 deletions
diff --git a/chromium/cc/mojo_embedder/async_layer_tree_frame_sink.h b/chromium/cc/mojo_embedder/async_layer_tree_frame_sink.h
index d32489d3f19..236d792b4b0 100644
--- a/chromium/cc/mojo_embedder/async_layer_tree_frame_sink.h
+++ b/chromium/cc/mojo_embedder/async_layer_tree_frame_sink.h
@@ -19,7 +19,12 @@
#include "components/viz/common/gpu/context_provider.h"
#include "components/viz/common/surfaces/parent_local_surface_id_allocator.h"
#include "components/viz/common/surfaces/surface_id.h"
-#include "mojo/public/cpp/bindings/binding.h"
+#include "mojo/public/cpp/bindings/associated_remote.h"
+#include "mojo/public/cpp/bindings/pending_associated_remote.h"
+#include "mojo/public/cpp/bindings/pending_receiver.h"
+#include "mojo/public/cpp/bindings/pending_remote.h"
+#include "mojo/public/cpp/bindings/receiver.h"
+#include "mojo/public/cpp/bindings/remote.h"
#include "services/viz/public/mojom/compositing/compositor_frame_sink.mojom.h"
namespace base {
@@ -74,12 +79,14 @@ class CC_MOJO_EMBEDDER_EXPORT AsyncLayerTreeFrameSink
bool HasUnbound() const;
- // Only one of |compositor_frame_sink_info| or
- // |compositor_frame_sink_associated_info| should be set.
- viz::mojom::CompositorFrameSinkPtrInfo compositor_frame_sink_info;
- viz::mojom::CompositorFrameSinkAssociatedPtrInfo
- compositor_frame_sink_associated_info;
- viz::mojom::CompositorFrameSinkClientRequest client_request;
+ // Only one of |compositor_frame_sink_remote| or
+ // |compositor_frame_sink_associated_remote| should be set.
+ mojo::PendingRemote<viz::mojom::CompositorFrameSink>
+ compositor_frame_sink_remote;
+ mojo::PendingAssociatedRemote<viz::mojom::CompositorFrameSink>
+ compositor_frame_sink_associated_remote;
+ mojo::PendingReceiver<viz::mojom::CompositorFrameSinkClient>
+ client_receiver;
};
struct CC_MOJO_EMBEDDER_EXPORT InitParams {
@@ -159,10 +166,10 @@ class CC_MOJO_EMBEDDER_EXPORT AsyncLayerTreeFrameSink
// be bound after calling BindToClient(). |compositor_frame_sink_ptr_| will
// point to message pipe we want to use.
viz::mojom::CompositorFrameSink* compositor_frame_sink_ptr_ = nullptr;
- viz::mojom::CompositorFrameSinkPtr compositor_frame_sink_;
- viz::mojom::CompositorFrameSinkAssociatedPtr
+ mojo::Remote<viz::mojom::CompositorFrameSink> compositor_frame_sink_;
+ mojo::AssociatedRemote<viz::mojom::CompositorFrameSink>
compositor_frame_sink_associated_;
- mojo::Binding<viz::mojom::CompositorFrameSinkClient> client_binding_;
+ mojo::Receiver<viz::mojom::CompositorFrameSinkClient> client_receiver_{this};
THREAD_CHECKER(thread_checker_);
const bool wants_animate_only_begin_frames_;